@@ -14,7 +14,7 @@
 #   limitations under the License.
 #
 
-from hsfs.core import feature_group_api, storage_connector_api, tags_api
+from hsfs.core import feature_group_api, storage_connector_api, tags_api, kafka_api
 
 
 class FeatureGroupBaseEngine:
@@ -26,6 +26,7 @@ class FeatureGroupBaseEngine:
         self._storage_connector_api = storage_connector_api.StorageConnectorApi(
             feature_store_id
         )
+        self._kafka_api = kafka_api.KafkaApi()
 
     def delete(self, feature_group):
         self._feature_group_api.delete(feature_group)
@@ -38,6 +39,16 @@ class FeatureGroupBaseEngine:
         """Remove a tag from a feature group."""
         self._tags_api.delete(feature_group, name)
 
-    def get_tags(self, feature_group, name):
-        """Get tag with a certain name or all tags for a feature group."""
-        return [tag.to_dict() for tag in self._tags_api.get(feature_group, name)]
+    def get_tag(self, feature_group, name):
+        """Get tag with a certain name."""
+        return self._tags_api.get(feature_group, name)[name]
+
+    def get_tags(self, feature_group):
+        """Get all tags for a feature group."""
+        return self._tags_api.get(feature_group)
+
+    def update_statistics_config(self, feature_group):
+        """Update the statistics configuration of a feature group."""
+        self._feature_group_api.update_metadata(
+            feature_group, feature_group, "updateStatsConfig"
+        )
