@@ -45,14 +45,19 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
 
         self._feature_group_api.save(feature_group)
         validation_id = None
-        if feature_group.validation_type != "NONE":
+        if (
+            feature_group.validation_type != "NONE"
+            and engine.get_instance().get_type() == "spark"
+        ):
+            # If the engine is Hive, the validation will be executed by
+            # the Hopsworks job ingesting the data
             validation = feature_group.validate(feature_dataframe)
             validation_id = validation.validation_id
 
         offline_write_options = write_options
         online_write_options = self.get_kafka_config(write_options)
 
-        engine.get_instance().save_dataframe(
+        return engine.get_instance().save_dataframe(
             feature_group,
             feature_dataframe,
             hudi_engine.HudiEngine.HUDI_BULK_INSERT
@@ -75,7 +80,12 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
         write_options,
     ):
         validation_id = None
-        if feature_group.validation_type != "NONE":
+        if (
+            feature_group.validation_type != "NONE"
+            and engine.get_instance().get_type() == "spark"
+        ):
+            # If the engine is Hive, the validation will be executed by
+            # the Hopsworks job ingesting the data
             validation = feature_group.validate(feature_dataframe)
             validation_id = validation.validation_id
 
@@ -90,7 +100,7 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
         if overwrite:
             self._feature_group_api.delete_content(feature_group)
 
-        engine.get_instance().save_dataframe(
+        return engine.get_instance().save_dataframe(
             feature_group,
             feature_dataframe,
             "bulk_insert" if overwrite else operation,
@@ -153,13 +163,13 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
             feature_group.validation_type,
         )
 
-    def sql(self, query, feature_store_name, dataframe_type, online):
+    def sql(self, query, feature_store_name, dataframe_type, online, read_options):
         if online:
             online_conn = self._storage_connector_api.get_online_connector()
         else:
             online_conn = None
         return engine.get_instance().sql(
-            query, feature_store_name, online_conn, dataframe_type
+            query, feature_store_name, online_conn, dataframe_type, read_options
         )
 
     def append_features(self, feature_group, new_features):
