@@ -210,8 +210,33 @@ class FeatureStore:
         """
         return self._storage_connector_api.get(name)
 
-    def sql(self, query, dataframe_type="default", online=False):
-        return self._feature_group_engine.sql(query, self._name, dataframe_type, online)
+    def sql(
+        self,
+        query: str,
+        dataframe_type: Optional[str] = "default",
+        online: Optional[bool] = False,
+        read_options: Optional[dict] = {},
+    ):
+        """Execute SQL command on the offline or online feature store database
+
+        Args:
+            query (str): The SQL query to execute.
+            dataframe_type (Optional[str], optional): The type of the returned dataframe. Defaults to "default"
+                which maps to Spark dataframe for the Spark Engine and Pandas dataframe for the Hive engine.
+            online (Optional[bool], optional): Set to true to execute the query against the online feature store.
+                Defaults to False.
+            read_options (Optional[dict], optional): Additional options to pass to the execution engine. Defaults to {}.
+                If running queries on the online feature store, users can provide an entry `{'external': True}`,
+                this instructs the library to use the `host` parameter in the [`hsfs.connection()`](project.md#connection) to establish the connection to the online feature store.
+                If not set, or set to False, the online feature store storage connector is used which relies on
+                the private ip.
+
+        Returns:
+            `DataFrame`: DataFrame depending on the chosen type.
+        """
+        return self._feature_group_engine.sql(
+            query, self._name, dataframe_type, online, read_options
+        )
 
     def get_online_storage_connector(self):
         """Get the storage connector for the Online Feature Store of the respective
